@@ -250,7 +250,7 @@ class Client:
         on_step: Optional[Callable[[], None]] = None,
     ) -> Union[SimulationResults, str]:
         while True:
-            if p.poll() is not None:
+            if p.poll() is not None and p.returncode != 0:
                 raise SimulationException(p.stderr.read(), p.returncode)
 
             line: bytes = p.stdout.readline()
